==> pastix_5.2.2.22.tar.bz2: pastix_5.2.2.22/src/matrix_drivers/src/laplacian.h <==
/* Copyright 2008 BORDEAUX I UNIVERSITY & INRIA 
**
** This file is part of the PaStiX parallel sparse matrix package.
**
** This software is governed by the CeCILL-C license under French law
** and abiding by the rules of distribution of free software. You can
** use, modify and/or redistribute the software under the terms of the
** CeCILL-C license as circulated by CEA, CNRS and INRIA at the following
** URL: "http://www.cecill.info".
** 
** As a counterpart to the access to the source code and rights to copy,
** modify and redistribute granted by the license, users are provided
** only with a limited warranty and the software's author, the holder of
** the economic rights, and the successive licensors have only limited
** liability.
** 
** In this respect, the user's attention is drawn to the risks associated
** with loading, using, modifying and/or developing or reproducing the
** software by the user in light of its specific status of free software,
** that may mean that it is complicated to manipulate, and that also
** therefore means that it is reserved for developers and experienced
** professionals having in-depth computer knowledge. Users are therefore
** encouraged to load and test the software's suitability as regards
** their requirements in conditions enabling the security of their
** systems and/or data to be ensured and, more generally, to use and
** operate it in the same conditions as regards security.
** 
** The fact that you are presently reading this means that you have had
** knowledge of the CeCILL-C license and that you accept its terms.
*/
/*
  File: laplacian.h

  Generate a laplacian 
  
  Example :
  >  2 -1  0  0
  > -1  2 -1  0 
  >  0  1  2 -1
  >  0  0 -1  2

*/

/*
  Function: genlaplacian

  Generate a laplacian of size *n*

  Parameters:
    n  	    - Size of the wanted matrix
    nnzeros - Number of non zeros in the produced matrice
    ia      - Index of first element of each column in *row* and *val*
    ja 	    - Row of eah element				       
    avals   - Value of each element				       
    rhs     - Right-hand-side member
    type    - Type of the matrix				       	 
    rhstype - Type of the right hand side.			       	 
 */
int genlaplacian(pastix_int_t     n, 
		 pastix_int_t    *nnzeros,
		 pastix_int_t   **ia, 
		 pastix_int_t   **ja,
		 pastix_float_t **avals,
		 pastix_float_t **rhs,
		 char           **type,
		 char           **rhstype);

==> pastix_5.2.3.tar.bz2: pastix_5.2.3/src/matrix_drivers/src/laplacian.h <==
/* Copyright 2008 BORDEAUX I UNIVERSITY & INRIA 
**
** This file is part of the PaStiX parallel sparse matrix package.
**
** This software is governed by the CeCILL-C license under French law
** and abiding by the rules of distribution of free software. You can
** use, modify and/or redistribute the software under the terms of the
** CeCILL-C license as circulated by CEA, CNRS and INRIA at the following
** URL: "http://www.cecill.info".
** 
** As a counterpart to the access to the source code and rights to copy,
** modify and redistribute granted by the license, users are provided
** only with a limited warranty and the software's author, the holder of
** the economic rights, and the successive licensors have only limited
** liability.
** 
** In this respect, the user's attention is drawn to the risks associated
** with loading, using, modifying and/or developing or reproducing the
** software by the user in light of its specific status of free software,
** that may mean that it is complicated to manipulate, and that also
** therefore means that it is reserved for developers and experienced
** professionals having in-depth computer knowledge. Users are therefore
** encouraged to load and test the software's suitability as regards
** their requirements in conditions enabling the security of their
** systems and/or data to be ensured and, more generally, to use and
** operate it in the same conditions as regards security.
** 
** The fact that you are presently reading this means that you have had
** knowledge of the CeCILL-C license and that you accept its terms.
*/
/*
  File: laplacian.h

  Generate a laplacian 
  
  Example :
  >  2 -1  0  0
  > -1  2 -1  0 
  >  0  1  2 -1
  >  0  0 -1  2

*/

/*
 * Function: genlaplacian
 *
 * Generate a laplacian of size *n*
 *
 * Parameters:
 *   n  	    - Size of the wanted matrix
 *   nnzeros - Number of non zeros in the produced matrice
 *   ia      - Index of first element of each column in *row* and *val*
 *   ja      - Row of eah element
 *   avals   - Value of each element
 *   rhs     - Right-hand-side member
 *   type    - Type of the matrix
 *   rhstype - Type of the right hand side.
 *   sym     - In complex : 1 symmetric, 0: hermitian
 */
int genlaplacian(pastix_int_t     n, 
		 pastix_int_t    *nnzeros,
		 pastix_int_t   **ia, 
		 pastix_int_t   **ja,
		 pastix_float_t **avals,
		 pastix_float_t **rhs,
		 char           **type,
		 char           **rhstype,
                 int              sym);
